@@ -20,7 +20,7 @@ OpenTracing::Role::SpanContext - Role for OpenTracing implementations.
 
 
 
-our $VERSION = '0.08_003';
+our $VERSION = '0.08_004';
 
 
 
@@ -28,6 +28,7 @@ use Moo::Role;
 
 use MooX::HandlesVia;
 
+use Data::GUID;
 use Sub::Trigger::Lock;
 use Types::Standard qw/HashRef Str/;
 
@@ -59,6 +60,15 @@ updating any values of the the attributes.
 
 
 
+has trace_id => (
+    is              => 'ro',
+#   isa             => Uuid, # not restraints here, do so when consuming this
+    init_arg        => undef,
+    default         => sub { Data::GUID->new },
+);
+
+
+
 # baggage_items
 #
 has baggage_items => (
